@@ -1,4 +1,4 @@
-from formatters.base import BaseFormatter
+from pylogwatch.formatters.base import BaseFormatter
 from dateutil.parser import parse
 
 import logging
@@ -33,4 +33,4 @@ class ApacheErrorLogFormatter (BaseFormatter):
         # set the Referer field as the culprit
         ref = line.split('referer: ')[-1]
         if ref!= line:
-            datadict['culprit'] = ref.strip()
\ No newline at end of file
+            datadict['culprit'] = ref.strip()
